==> react-admin-base-bootstrap-0.9.1.tgz: package/lib/esm/Components/ThemeProvider.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { createContext, useContext, useEffect, useMemo } from "react";
import { useLocalStorage } from "react-admin-base";
const ThemeContext = createContext(null);
const AllThemesContext = createContext(null);
export function useTheme() {
    return useContext(ThemeContext);
}
export function useAllThemes() {
    return useContext(AllThemesContext);
}
export default function ThemeProvider({ themes, defaultTheme, children }) {
    const state = useLocalStorage('theme');
    const [theme, setTheme] = state;
    const rTheme = theme || defaultTheme || 'light';
    useEffect(function () {
        const promise = (themes[rTheme] || themes[defaultTheme]).css()
            .then(css => {
            css.default.use();
            return css;
        });
        return function () {
            promise.then(css => css.default.unuse());
        };
    }, [theme]);
    const val = useMemo(() => [rTheme, setTheme], [rTheme, setTheme]);
    return React.createElement(AllThemesContext.Provider, { value: themes },
        React.createElement(ThemeContext.Provider, { value: val }, children));
}
export function rawCssLoader(cb) {
    return __awaiter(this, void 0, void 0, function* () {
        const styleTag = document.createElement('style');
        let loaded = false;
        return {
            default: {
                use: function () {
                    return __awaiter(this, void 0, void 0, function* () {
                        document.head.appendChild(styleTag);
                        if (!loaded) {
                            loaded = true;
                            styleTag.innerHTML = yield cb();
                        }
                    });
                },
                unuse: function () {
                    document.head.removeChild(styleTag);
                }
            }
        };
    });
}
export function urlCssLoader(link) {
    return __awaiter(this, void 0, void 0, function* () {
        const linkTag = document.createElement('link');
        linkTag.rel = 'stylesheet';
        linkTag.type = 'text/css';
        linkTag.href = link;
        return {
            default: {
                use: function () {
                    document.head.appendChild(linkTag);
                },
                unuse: function () {
                    document.head.removeChild(linkTag);
                }
            }
        };
    });
}

==> react-admin-base-bootstrap-0.9.2.tgz: package/lib/esm/Components/ThemeProvider.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { createContext, useContext, useEffect, useMemo } from "react";
import { useLocalStorage } from "react-admin-base";
const ThemeContext = createContext(null);
const AllThemesContext = createContext(null);
export function useTheme() {
    return useContext(ThemeContext);
}
export function useAllThemes() {
    return useContext(AllThemesContext);
}
export default function ThemeProvider({ themes, defaultTheme, children }) {
    const state = useLocalStorage('theme');
    const [theme, setTheme] = state;
    const rTheme = theme || defaultTheme || 'light';
    useEffect(function () {
        const promise = Promise.resolve((themes[rTheme] || themes[defaultTheme]).css())
            .then(css => {
            css.default.use();
            return css;
        });
        return function () {
            promise.then(css => css.default.unuse());
        };
    }, [theme]);
    const val = useMemo(() => [rTheme, setTheme], [rTheme, setTheme]);
    return React.createElement(AllThemesContext.Provider, { value: themes },
        React.createElement(ThemeContext.Provider, { value: val }, children));
}
export function rawCssLoader(cb) {
    const styleTag = document.createElement('style');
    let loaded = false;
    return () => ({
        default: {
            use: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    document.head.appendChild(styleTag);
                    if (!loaded) {
                        loaded = true;
                        styleTag.innerHTML = yield cb();
                    }
                });
            },
            unuse: function () {
                document.head.removeChild(styleTag);
            }
        }
    });
}
export function urlCssLoader(link) {
    const linkTag = document.createElement('link');
    linkTag.rel = 'stylesheet';
    linkTag.type = 'text/css';
    linkTag.href = link;
    return () => ({
        default: {
            use: function () {
                document.head.appendChild(linkTag);
            },
            unuse: function () {
                document.head.removeChild(linkTag);
            }
        }
    });
}
